package com.ruoyi.project.project.item.service;

import com.ruoyi.project.project.item.domain.Item;

import java.util.List;

/**
 * 物品 服务层
 * 
 * @author luoluo
 */
public interface IItemService
{
    /**
     * 查询信息
     * 
     * @param id 物品ID
     * @return 物品信息
     */
    public Item selectItemById(Integer id);

    /**
     * 查询物品列表
     * 
     * @param item 物品信息
     * @return 物品集合
     */
    public List<Item> selectItemList(Item item);

    public List<Item> selectItemByCaseNo(String caseNo);

    /**
     * 新增物品
     * 
     * @param item 物品信息
     * @return 结果
     */
    public int insertItem(Item item);

    /**
     * 修改物品
     * 
     * @param item 物品信息
     * @return 结果
     */
    public int updateItem(Item item);

    /**
     * 删除物品信息
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteItemByIds(String ids);

    /**
     * 根据案件查询是否有物品
     * @param id
     * @return
     */
    public int selectItemByCaseId(String id);

    /**
     *
     * @param item
     * @return
     */
    int selectItemByItemNo(Item item);


}
